@@ -3,7 +3,6 @@ import time
 
 from .exceptions import *
 
-
 class HoneyGain:
     def __init__(self, API_PREFIX_URL: str = "/api", API_VERSION: str = "/v1", API_DOMAIN: str = "https://dashboard.honeygain.com") -> None:
         """Initialise HoneyGain API Client. """
@@ -61,7 +60,7 @@ class HoneyGain:
         return True
 
     def signup(self, email: str, password: str, referral: str = "freemoney") -> str:
-        """Creates a new account with the given `email` and `password and links it to `referral``"""
+        """Creates a new account with the given `email` and `password and links it to `referral`"""
 
         if referral is None:
             r = self.__make_request('POST', "/users", json={
@@ -203,6 +202,13 @@ class HoneyGain:
 
         return notifications_data if r.ok else False
 
+    @staticmethod
+    def coupon(coupon_code):
+        """Returns information about a `coupon/referral` code"""
+        r = HoneyGain.__make_request("GET", f"/coupons/{coupon_code}")
+
+        return r.json()
+
     def payouts(self):
         """Returns payouts info. """
         self.handle_not_logged_in()
